import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;
import java.util.Scanner;

public class AccountApp {

    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;

    private boolean isControlRunning;
    private String name;
    private String password;
    private String function;
    private int id;

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "");
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            System.out.println("\n\nIt seems to have worked\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    /**
     * Read and write some example data.
     */
    private void processData() throws Exception {

        isControlRunning = true;

        while (isControlRunning) {
            this.function = askInput("What would you like to do?\n " +
                    "(c)reate, (r)ead, (u)pdate, (d)elete, (q)uit or anything else.");
            doFunction();
        }
    }

    private void doFunction() throws Exception{
        if (function.equalsIgnoreCase("c")) {
            create();
            return;
        }

        if (function.equalsIgnoreCase("r")) {
            read();
            return;
        }

        if (function.equalsIgnoreCase("u")) {
            update();
            return;
        }

        if (function.equalsIgnoreCase("d")) {
            delete();
            return;
        }
        // anything else set isControlRunning to false;
        isControlRunning = false;

    }

    private void create() throws Exception {
        name = askInput("What is the name of the account?");
        password = askInput("What is the password of the account?");
        accountDao.create(new Account(name, password));
    }

    private void read() throws Exception {
        id = askId();
        name = accountDao.queryForId(id).getName();
        password = accountDao.queryForId(id).getPassword();
        System.out.println("ID: " + id + " Name: " + name + " Password: " + password);
    }

    private void update() throws Exception {
        id = askId();
        password = askInput("What is the password?");
        accountDao.queryForId(id).setPassword(password);
    }

    private void delete() throws Exception {
        id = askId();
        accountDao.deleteById(id);
    }

    private int askId() {
        return Integer.parseInt(askInput("What is the id number?"));
    }

    private String askInput(String message) {
        Scanner reader = new Scanner(System.in);
        System.out.println(message);
        return reader.nextLine();
    }

    /**
     * Setup our  DAOs
     */
    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }
}